/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 101 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 105 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 108 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 181 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qfont.sip"
#include <qfont.h>
#line 184 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 187 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 190 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpen.sip"
#include <qpen.h>
#line 193 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 198 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 201 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 204 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 207 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 210 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 213 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 216 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 219 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 222 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 225 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 228 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 231 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 234 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 237 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 240 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSlice.cpp"


class sipQtCharts_QPieSlice : public ::QtCharts::QPieSlice
{
public:
    sipQtCharts_QPieSlice(::QObject*);
    sipQtCharts_QPieSlice(::QString, ::qreal, ::QObject*);
    virtual ~sipQtCharts_QPieSlice();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtCharts_QPieSlice(const sipQtCharts_QPieSlice &);
    sipQtCharts_QPieSlice &operator = (const sipQtCharts_QPieSlice &);

    char sipPyMethods[7];
};

sipQtCharts_QPieSlice::sipQtCharts_QPieSlice(::QObject*a0): ::QtCharts::QPieSlice(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QPieSlice::sipQtCharts_QPieSlice(::QString a0, ::qreal a1, ::QObject*a2): ::QtCharts::QPieSlice(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QPieSlice::~sipQtCharts_QPieSlice()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtCharts_QPieSlice::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtChart_qt_metaobject(sipPySelf, sipType_QtCharts_QPieSlice);

    return ::QtCharts::QPieSlice::metaObject();
}

int sipQtCharts_QPieSlice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtCharts::QPieSlice::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtChart_qt_metacall(sipPySelf, sipType_QtCharts_QPieSlice, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtCharts_QPieSlice::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtChart_qt_metacast(sipPySelf, sipType_QtCharts_QPieSlice, _clname, &sipCpp) ? sipCpp : ::QtCharts::QPieSlice::qt_metacast(_clname));
}

bool sipQtCharts_QPieSlice::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtCharts::QPieSlice::event(a0);

    extern bool sipVH_QtChart_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtChart_5(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QPieSlice::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtCharts::QPieSlice::eventFilter(a0, a1);

    extern bool sipVH_QtChart_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtChart_4(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtCharts_QPieSlice::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtCharts::QPieSlice::timerEvent(a0);
        return;
    }

    extern void sipVH_QtChart_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtChart_3(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QPieSlice::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtCharts::QPieSlice::childEvent(a0);
        return;
    }

    extern void sipVH_QtChart_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtChart_2(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QPieSlice::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtCharts::QPieSlice::customEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QPieSlice::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QPieSlice::connectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QPieSlice::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QPieSlice::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setLabel, "setLabel(self, label: str|None)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setLabel(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setLabel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QString* a0;
        int a0State = 0;
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setLabel(*a0);
            sipReleaseType(a0, sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setLabel, doc_QtCharts_QPieSlice_setLabel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_label, "label(self) -> str");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_label(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_label(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->label());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_label, doc_QtCharts_QPieSlice_label);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setValue, "setValue(self, value: float)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setValue(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, &a0))
        {
            sipCpp->setValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setValue, doc_QtCharts_QPieSlice_setValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_value, "value(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_value(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_value(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->value();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_value, doc_QtCharts_QPieSlice_value);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setLabelVisible, "setLabelVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setLabelVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setLabelVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QPieSlice *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, &a0))
        {
            sipCpp->setLabelVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setLabelVisible, doc_QtCharts_QPieSlice_setLabelVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_isLabelVisible, "isLabelVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_isLabelVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_isLabelVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isLabelVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_isLabelVisible, doc_QtCharts_QPieSlice_isLabelVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setExploded, "setExploded(self, exploded: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setExploded(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setExploded(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QPieSlice *sipCpp;

        static const char *sipKwdList[] = {
            sipName_exploded,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, &a0))
        {
            sipCpp->setExploded(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setExploded, doc_QtCharts_QPieSlice_setExploded);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_isExploded, "isExploded(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_isExploded(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_isExploded(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isExploded();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_isExploded, doc_QtCharts_QPieSlice_isExploded);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setPen, "setPen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setPen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setPen, doc_QtCharts_QPieSlice_setPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_pen, "pen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_pen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_pen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->pen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_pen, doc_QtCharts_QPieSlice_pen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_borderColor, "borderColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_borderColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_borderColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->borderColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_borderColor, doc_QtCharts_QPieSlice_borderColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setBorderColor, "setBorderColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setBorderColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setBorderColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setBorderColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setBorderColor, doc_QtCharts_QPieSlice_setBorderColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_borderWidth, "borderWidth(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_borderWidth(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_borderWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->borderWidth();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_borderWidth, doc_QtCharts_QPieSlice_borderWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setBorderWidth, "setBorderWidth(self, width: int)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setBorderWidth(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setBorderWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, &a0))
        {
            sipCpp->setBorderWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setBorderWidth, doc_QtCharts_QPieSlice_setBorderWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setBrush, "setBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setBrush, doc_QtCharts_QPieSlice_setBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_brush, "brush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_brush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_brush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->brush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_brush, doc_QtCharts_QPieSlice_brush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_color, "color(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_color(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_color(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->color());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_color, doc_QtCharts_QPieSlice_color);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setColor, "setColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setColor, doc_QtCharts_QPieSlice_setColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setLabelBrush, "setLabelBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setLabelBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setLabelBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setLabelBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setLabelBrush, doc_QtCharts_QPieSlice_setLabelBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_labelBrush, "labelBrush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_labelBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_labelBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->labelBrush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_labelBrush, doc_QtCharts_QPieSlice_labelBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_labelColor, "labelColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_labelColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_labelColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->labelColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_labelColor, doc_QtCharts_QPieSlice_labelColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setLabelColor, "setLabelColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setLabelColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setLabelColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setLabelColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setLabelColor, doc_QtCharts_QPieSlice_setLabelColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setLabelFont, "setLabelFont(self, font: QFont)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setLabelFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setLabelFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFont* a0;
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setLabelFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setLabelFont, doc_QtCharts_QPieSlice_setLabelFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_labelFont, "labelFont(self) -> QFont");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_labelFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_labelFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::QFont*sipRes;

            sipRes = new ::QFont(sipCpp->labelFont());

            return sipConvertFromNewType(sipRes, sipType_QFont, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_labelFont, doc_QtCharts_QPieSlice_labelFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setLabelArmLengthFactor, "setLabelArmLengthFactor(self, factor: float)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setLabelArmLengthFactor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setLabelArmLengthFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, &a0))
        {
            sipCpp->setLabelArmLengthFactor(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setLabelArmLengthFactor, doc_QtCharts_QPieSlice_setLabelArmLengthFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_labelArmLengthFactor, "labelArmLengthFactor(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_labelArmLengthFactor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_labelArmLengthFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->labelArmLengthFactor();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_labelArmLengthFactor, doc_QtCharts_QPieSlice_labelArmLengthFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setExplodeDistanceFactor, "setExplodeDistanceFactor(self, factor: float)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setExplodeDistanceFactor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setExplodeDistanceFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, &a0))
        {
            sipCpp->setExplodeDistanceFactor(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setExplodeDistanceFactor, doc_QtCharts_QPieSlice_setExplodeDistanceFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_explodeDistanceFactor, "explodeDistanceFactor(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_explodeDistanceFactor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_explodeDistanceFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->explodeDistanceFactor();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_explodeDistanceFactor, doc_QtCharts_QPieSlice_explodeDistanceFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_percentage, "percentage(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_percentage(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_percentage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->percentage();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_percentage, doc_QtCharts_QPieSlice_percentage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_startAngle, "startAngle(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_startAngle(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_startAngle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->startAngle();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_startAngle, doc_QtCharts_QPieSlice_startAngle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_angleSpan, "angleSpan(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_angleSpan(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_angleSpan(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->angleSpan();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_angleSpan, doc_QtCharts_QPieSlice_angleSpan);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_series, "series(self) -> QPieSeries|None");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_series(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_series(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::QtCharts::QPieSeries*sipRes;

            sipRes = sipCpp->series();

            return sipConvertFromType(sipRes, sipType_QtCharts_QPieSeries, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_series, doc_QtCharts_QPieSlice_series);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_labelPosition, "labelPosition(self) -> QPieSlice.LabelPosition");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_labelPosition(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_labelPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp))
        {
            ::QtCharts::QPieSlice::LabelPosition sipRes;

            sipRes = sipCpp->labelPosition();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtCharts_QPieSlice_LabelPosition);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_labelPosition, doc_QtCharts_QPieSlice_labelPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSlice_setLabelPosition, "setLabelPosition(self, position: QPieSlice.LabelPosition)");

extern "C" {static PyObject *meth_QtCharts_QPieSlice_setLabelPosition(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSlice_setLabelPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPieSlice::LabelPosition a0;
        ::QtCharts::QPieSlice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QtCharts_QPieSlice, &sipCpp, sipType_QtCharts_QPieSlice_LabelPosition, &a0))
        {
            sipCpp->setLabelPosition(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSlice, sipName_setLabelPosition, doc_QtCharts_QPieSlice_setLabelPosition);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QPieSlice(void *, const sipTypeDef *);}
static void *cast_QtCharts_QPieSlice(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QPieSlice *sipCpp = reinterpret_cast< ::QtCharts::QPieSlice *>(sipCppV);

    if (targetType == sipType_QtCharts_QPieSlice)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QPieSlice(void *, int);}
static void release_QtCharts_QPieSlice(void *sipCppV, int)
{
    ::QtCharts::QPieSlice *sipCpp = reinterpret_cast< ::QtCharts::QPieSlice *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtCharts_QPieSlice(Py_ssize_t);}
static void *array_QtCharts_QPieSlice(Py_ssize_t sipNrElem)
{
    return new ::QtCharts::QPieSlice[sipNrElem];
}


extern "C" {static void array_delete_QtCharts_QPieSlice(void *);}
static void array_delete_QtCharts_QPieSlice(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtCharts::QPieSlice *>(sipCpp);
}


extern "C" {static void dealloc_QtCharts_QPieSlice(sipSimpleWrapper *);}
static void dealloc_QtCharts_QPieSlice(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtCharts_QPieSlice *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QPieSlice(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtCharts_QPieSlice(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtCharts_QPieSlice(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtCharts_QPieSlice *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtCharts_QPieSlice(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QString* a0;
        int a0State = 0;
        ::qreal a1;
        ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1d|JH", sipType_QString, &a0, &a0State, &a1, sipType_QObject, &a2, sipOwner))
        {
            sipCpp = new sipQtCharts_QPieSlice(*a0, a1, a2);
            sipReleaseType(a0, sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QPieSlice[] = {{10, 0, 1}};


static PyMethodDef methods_QtCharts_QPieSlice[] = {
    {sipName_angleSpan, meth_QtCharts_QPieSlice_angleSpan, METH_VARARGS, doc_QtCharts_QPieSlice_angleSpan},
    {sipName_borderColor, meth_QtCharts_QPieSlice_borderColor, METH_VARARGS, doc_QtCharts_QPieSlice_borderColor},
    {sipName_borderWidth, meth_QtCharts_QPieSlice_borderWidth, METH_VARARGS, doc_QtCharts_QPieSlice_borderWidth},
    {sipName_brush, meth_QtCharts_QPieSlice_brush, METH_VARARGS, doc_QtCharts_QPieSlice_brush},
    {sipName_color, meth_QtCharts_QPieSlice_color, METH_VARARGS, doc_QtCharts_QPieSlice_color},
    {sipName_explodeDistanceFactor, meth_QtCharts_QPieSlice_explodeDistanceFactor, METH_VARARGS, doc_QtCharts_QPieSlice_explodeDistanceFactor},
    {sipName_isExploded, meth_QtCharts_QPieSlice_isExploded, METH_VARARGS, doc_QtCharts_QPieSlice_isExploded},
    {sipName_isLabelVisible, meth_QtCharts_QPieSlice_isLabelVisible, METH_VARARGS, doc_QtCharts_QPieSlice_isLabelVisible},
    {sipName_label, meth_QtCharts_QPieSlice_label, METH_VARARGS, doc_QtCharts_QPieSlice_label},
    {sipName_labelArmLengthFactor, meth_QtCharts_QPieSlice_labelArmLengthFactor, METH_VARARGS, doc_QtCharts_QPieSlice_labelArmLengthFactor},
    {sipName_labelBrush, meth_QtCharts_QPieSlice_labelBrush, METH_VARARGS, doc_QtCharts_QPieSlice_labelBrush},
    {sipName_labelColor, meth_QtCharts_QPieSlice_labelColor, METH_VARARGS, doc_QtCharts_QPieSlice_labelColor},
    {sipName_labelFont, meth_QtCharts_QPieSlice_labelFont, METH_VARARGS, doc_QtCharts_QPieSlice_labelFont},
    {sipName_labelPosition, meth_QtCharts_QPieSlice_labelPosition, METH_VARARGS, doc_QtCharts_QPieSlice_labelPosition},
    {sipName_pen, meth_QtCharts_QPieSlice_pen, METH_VARARGS, doc_QtCharts_QPieSlice_pen},
    {sipName_percentage, meth_QtCharts_QPieSlice_percentage, METH_VARARGS, doc_QtCharts_QPieSlice_percentage},
    {sipName_series, meth_QtCharts_QPieSlice_series, METH_VARARGS, doc_QtCharts_QPieSlice_series},
    {sipName_setBorderColor, meth_QtCharts_QPieSlice_setBorderColor, METH_VARARGS, doc_QtCharts_QPieSlice_setBorderColor},
    {sipName_setBorderWidth, meth_QtCharts_QPieSlice_setBorderWidth, METH_VARARGS, doc_QtCharts_QPieSlice_setBorderWidth},
    {sipName_setBrush, meth_QtCharts_QPieSlice_setBrush, METH_VARARGS, doc_QtCharts_QPieSlice_setBrush},
    {sipName_setColor, meth_QtCharts_QPieSlice_setColor, METH_VARARGS, doc_QtCharts_QPieSlice_setColor},
    {sipName_setExplodeDistanceFactor, meth_QtCharts_QPieSlice_setExplodeDistanceFactor, METH_VARARGS, doc_QtCharts_QPieSlice_setExplodeDistanceFactor},
    {sipName_setExploded, SIP_MLMETH_CAST(meth_QtCharts_QPieSlice_setExploded), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QPieSlice_setExploded},
    {sipName_setLabel, meth_QtCharts_QPieSlice_setLabel, METH_VARARGS, doc_QtCharts_QPieSlice_setLabel},
    {sipName_setLabelArmLengthFactor, meth_QtCharts_QPieSlice_setLabelArmLengthFactor, METH_VARARGS, doc_QtCharts_QPieSlice_setLabelArmLengthFactor},
    {sipName_setLabelBrush, meth_QtCharts_QPieSlice_setLabelBrush, METH_VARARGS, doc_QtCharts_QPieSlice_setLabelBrush},
    {sipName_setLabelColor, meth_QtCharts_QPieSlice_setLabelColor, METH_VARARGS, doc_QtCharts_QPieSlice_setLabelColor},
    {sipName_setLabelFont, meth_QtCharts_QPieSlice_setLabelFont, METH_VARARGS, doc_QtCharts_QPieSlice_setLabelFont},
    {sipName_setLabelPosition, meth_QtCharts_QPieSlice_setLabelPosition, METH_VARARGS, doc_QtCharts_QPieSlice_setLabelPosition},
    {sipName_setLabelVisible, SIP_MLMETH_CAST(meth_QtCharts_QPieSlice_setLabelVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QPieSlice_setLabelVisible},
    {sipName_setPen, meth_QtCharts_QPieSlice_setPen, METH_VARARGS, doc_QtCharts_QPieSlice_setPen},
    {sipName_setValue, meth_QtCharts_QPieSlice_setValue, METH_VARARGS, doc_QtCharts_QPieSlice_setValue},
    {sipName_startAngle, meth_QtCharts_QPieSlice_startAngle, METH_VARARGS, doc_QtCharts_QPieSlice_startAngle},
    {sipName_value, meth_QtCharts_QPieSlice_value, METH_VARARGS, doc_QtCharts_QPieSlice_value}
};

static sipEnumMemberDef enummembers_QtCharts_QPieSlice[] = {
    {sipName_LabelInsideHorizontal, static_cast<int>(::QtCharts::QPieSlice::LabelInsideHorizontal), 58},
    {sipName_LabelInsideNormal, static_cast<int>(::QtCharts::QPieSlice::LabelInsideNormal), 58},
    {sipName_LabelInsideTangential, static_cast<int>(::QtCharts::QPieSlice::LabelInsideTangential), 58},
    {sipName_LabelOutside, static_cast<int>(::QtCharts::QPieSlice::LabelOutside), 58},
};

PyDoc_STRVAR(doc_QtCharts_QPieSlice, "\1QPieSlice(parent: QObject|None = None)\n"
"QPieSlice(label: str|None, value: float, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QPieSlice[] = {
    {"doubleClicked()", "\1doubleClicked(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"released()", "\1released(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"pressed()", "\1pressed(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"hovered(bool)", "\1hovered(self, state: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"clicked()", "\1clicked(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelColorChanged()", "\1labelColorChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"borderWidthChanged()", "\1borderWidthChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"borderColorChanged()", "\1borderColorChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"colorChanged()", "\1colorChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"angleSpanChanged()", "\1angleSpanChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"startAngleChanged()", "\1startAngleChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"percentageChanged()", "\1percentageChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelFontChanged()", "\1labelFontChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelBrushChanged()", "\1labelBrushChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"brushChanged()", "\1brushChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"penChanged()", "\1penChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelVisibleChanged()", "\1labelVisibleChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"valueChanged()", "\1valueChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelChanged()", "\1labelChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QPieSlice = {
    &::QtCharts::QPieSlice::staticMetaObject,
    0,
    signals_QtCharts_QPieSlice,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QPieSlice = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QPieSlice,
        SIP_NULLPTR,
        &plugin_QtCharts_QPieSlice,
    },
    {
        sipNameNr_QPieSlice,
        {0, 0, 1},
        34, methods_QtCharts_QPieSlice,
        4, enummembers_QtCharts_QPieSlice,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtCharts_QPieSlice,
    -1,
    -1,
    supers_QtCharts_QPieSlice,
    SIP_NULLPTR,
    init_type_QtCharts_QPieSlice,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QPieSlice,
    SIP_NULLPTR,
    array_QtCharts_QPieSlice,
    SIP_NULLPTR,
    release_QtCharts_QPieSlice,
    cast_QtCharts_QPieSlice,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtCharts_QPieSlice,
    sizeof (::QtCharts::QPieSlice),
};
